package Qt::Gui::QWindowStateChangeEvent;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QWindowStateChangeEvent
# file     : QtGui/qevent.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Core::QEvent/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QWindowStateChangeEvent

=head1 PUBLIC METHODS

=over

=item   QWindowStateChangeEvent(QFlags<Qt::WindowState> aOldState)

=item   QWindowStateChangeEvent(QFlags<Qt::WindowState> aOldState, bool isOverride)

=item   ~QWindowStateChangeEvent()

=item  bool isOverride()

=item  QFlags<Qt::WindowState> oldState()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
